@@ -1,13 +1,28 @@
+
+import warnings
+warnings.filterwarnings('ignore')
+
 from .lexer import generator
 from .parser import parser
 from .objects import ImageRepr
-from .core import Runner
 
 from . import operations
 from . import cv
 
+lexer = generator.build()
+parser = parser.build()
+
+from .core import Runner
+
 __title__ = 'f-stop'
 __author__ = 'Tom-the-Bomb'
-__version__ = '0.2.2'
+__version__ = '0.2.14'
 __license__ = 'MIT'
-__copyright__ = 'Copyright 2021 Tom the Bomb'
\ No newline at end of file
+__copyright__ = 'Copyright 2021 Tom the Bomb'
+
+__all__: tuple = (
+    'ImageRepr',
+    'lexer', 
+    'parser', 
+    'Runner',
+)
\ No newline at end of file
