@@ -163,6 +163,23 @@ def ntuple(state: ParserState, p: list) -> tuple:
     else:
         return p[0]() + (p[1](),) if len(p) == 3 else p[0]()
 
+@parser.production('vartuple_start : LEFT_PAREN variable COMMA')
+@evaluate
+def vartuple_start(state: ParserState, p: list) -> tuple:
+    return (p[1],)
+
+@parser.production('vartuple_start : vartuple_start variable COMMA')
+@evaluate
+def vartuple_body(state: ParserState, p: list) -> tuple:
+    return p[0]() + (p[1],)
+
+@parser.production('vartuple : vartuple_start RIGHT_PAREN')
+@parser.production('vartuple : vartuple_start variable RIGHT_PAREN')
+@evaluate
+def vartuple(state: ParserState, p: list) -> tuple:
+    tup = p[0]() + (p[1],) if len(p) == 3 else p[0]()
+    return tup
+
 @parser.production('ntuple : TEXTSIZE font COMMA string')
 @evaluate
 def get_textsize(state: ParserState, p: list) -> tuple:
@@ -205,6 +222,11 @@ def str_concat(state: ParserState, p: list) -> str:
 def tuple_concat(state: ParserState, p: list) -> tuple:
     return p[0]() + p[-1]()
 
+@parser.production('vartuple : vartuple ADD vartuple')
+@evaluate
+def vartuple_concat(state: ParserState, p: list) -> tuple:
+    return p[0]() + p[-1]()
+    
 @parser.production('sequence : sequence ADD sequence')
 @evaluate
 def seq_concat(state: ParserState, p: list) -> list:
@@ -264,12 +286,31 @@ def new_statement(state: ParserState, p: list) -> Optional[ImageRepr]:
         state.env[name] = image
         return image
 
+@parser.production('expr : SPLIT variable AS vartuple')
+@evaluate
+def split_statement(state: ParserState, p: list) -> None:
+    var, bands = p[1], p[3]()
+    img = get_var(state, var)
+    chan = img.image.split()
+
+    if (a := len(bands)) != (b := len(chan)):
+        raise ValueError('Got %s bands from the image, received %s variables to store as' % (b, a))
+    else:
+        for var, band in zip(bands, chan):
+            img = ImageRepr(band)
+            state.env[var] = img
+
  
-@parser.production('expr : MERGE string sequence AS variable')
+@parser.production('expr : MERGE string vartuple AS variable')
 @evaluate
 def merge_statement(state: ParserState, p: list) -> Optional[ImageRepr]:
     mode, bands, name = p[1](), p[2](), p[4]
-    image = Image.merge(mode, tuple(bands))
+
+    bands = tuple(getattr(
+        get_var(state, i), 'image', None) for i in bands
+    )
+
+    image = Image.merge(mode, bands)
     image = ImageRepr(image)
     state.env[name] = image
     return image
@@ -334,14 +375,16 @@ def convert_statement(state: ParserState, p: list) -> None:
 @evaluate
 def save_statement(state: ParserState, p: list) -> Union[str, BytesIO]:
     img = get_var(state, p[1], (ImageRepr, list))
-    if isinstance(img, list):
-        options = {}
-        try:
-            i = p.index(Token('DURATION', r'DURATION')) + 1
-            j = p.index(Token('LOOP', r'LOOP')) + 1
-            options['duration'], options['loop'] = p[i](), p[j]()
-        except (ValueError, TypeError, IndexError):
-            pass
+    
+    options = {}
+    if (dur_tok := Token('DURATION', r'DURATION')) in p:
+        i = p.index(dur_tok) + 1
+        options['duration'] = p[i]()
+        
+    if (loop_tok := Token('LOOP', r'LOOP')) in p:
+        j = p.index(loop_tok) + 1
+        options['loop'] = p[j]()
+        
     if Token('STREAM', r'STREAM') not in p:
         if isinstance(img, ImageRepr):
             img.image.save(p[2]())
